pub unsafe trait AssignableTo<T: ReferenceType>: ReferenceType { }Expand description
Marker trait indicating Self can be assigned to T.
This is true when T is a superclass or superinterface of Self.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl<T: ReferenceType> AssignableTo<T> for T
A type is always assignable to itself.